"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yeoman_test_1 = __importDefault(require("yeoman-test"));
const __utils__1 = require("../../../__utils__");
describe("toBeYeomanTestRunResult", () => {
    describe("when given something that isn't a YeomanTest.RunResult", () => {
        it("fails on a number", () => {
            expect(() => {
                expect(2).toBeYeomanTestRunResult();
            }).toThrow("Expected 2 to be a YeomanTest.RunResult");
        });
        it("fails on a boolean", () => {
            expect(() => {
                expect(true).toBeYeomanTestRunResult();
            }).toThrow("Expected true to be a YeomanTest.RunResult");
        });
        it("fails on a string", () => {
            expect(() => {
                expect("foobar").toBeYeomanTestRunResult();
            }).toThrow("Expected foobar to be a YeomanTest.RunResult");
        });
        it("fails on an empty object", () => {
            expect(() => {
                expect({}).toBeYeomanTestRunResult();
            }).toThrow("Expected [object Object] to be a YeomanTest.RunResult");
        });
        it("fails on a function", () => {
            const nullOp = () => {
                return;
            };
            expect(() => {
                expect(nullOp).toBeYeomanTestRunResult();
            }).toThrow(`Expected ${nullOp.toString()} to be a YeomanTest.RunResult`);
        });
    });
    describe("when given a YeomanTest.RunResult", () => {
        let result;
        beforeAll(async () => {
            result = await yeoman_test_1.default.create(__utils__1.EmptyTestGenerator, {
                namespace: "test:empty",
            }).run();
        });
        it("passes", () => {
            expect(() => {
                expect(result).toBeYeomanTestRunResult();
            }).not.toThrow();
        });
    });
    it("passes on an object that looks like a YeomanTest.RunResult", () => {
        const mockRunResult = {
            assertFile: jest.fn(),
            assertNoFile: jest.fn(),
            assertFileContent: jest.fn(),
            assertEqualsFileContent: jest.fn(),
            assertNoFileContent: jest.fn(),
            assertTextEqual: jest.fn(),
            assertObjectContent: jest.fn(),
            assertNoObjectContent: jest.fn(),
            assertJsonFileContent: jest.fn(),
            assertNoJsonFileContent: jest.fn(),
            env: {},
            fs: {},
        };
        expect(() => {
            expect(mockRunResult).toBeYeomanTestRunResult();
        }).not.toThrow();
    });
});
//# sourceMappingURL=toBeYeomanTestRunResult.matcher.test.js.map