"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yeoman_test_1 = __importDefault(require("yeoman-test"));
const __utils__1 = require("../../../__utils__");
describe("toHaveDevDependencyComment", () => {
    it("fails if given something other than a YeomanTest.RunResult", () => {
        expect(() => {
            expect(2).toHaveDevDependencyComment("node");
        }).toThrow("Expected 2 to be a YeomanTest.RunResult");
    });
    describe("when given a YeomanTest.RunResult", () => {
        let result;
        describe("that contains a package.json file with devDependenciesComments", () => {
            beforeAll(async () => {
                result = await yeoman_test_1.default.create(__utils__1.DevDependenciesTestGenerator, {
                    namespace: "test:dev-dependencies",
                }).run();
            });
            it("passes if the package.json lists a comment for the provided devDependency", () => {
                expect(() => {
                    expect(result).toHaveDevDependencyComment("typescript");
                }).not.toThrow();
            });
            it("fails if package.json does not list a comment for the provided devDependency", () => {
                expect(() => {
                    expect(result).toHaveDevDependencyComment("eslint");
                }).toThrow("Expected run result package.json to have a devDependency comment for eslint");
            });
        });
        describe("that contains a package.json file without devDependencies", () => {
            beforeAll(async () => {
                result = await yeoman_test_1.default.create(__utils__1.NoDevDependenciesTestGenerator, {
                    namespace: "test:no-dev-dependencies",
                }).run();
            });
            it("fails with an error about devDependenciesComments being missing", () => {
                expect(() => {
                    expect(result).toHaveDevDependencyComment("typescript");
                }).toThrow("Expected run result package.json to have a devDependenciesComments key");
            });
        });
        describe("that does not contain a package.json file", () => {
            beforeAll(async () => {
                result = await yeoman_test_1.default.create(__utils__1.EmptyTestGenerator, {
                    namespace: "test:empty",
                }).run();
            });
            it("fails with an error about package.json being missing", () => {
                expect(() => {
                    expect(result).toHaveDevDependencyComment("typescript");
                }).toThrow("Expected run result to contain a package.json file");
            });
        });
    });
});
//# sourceMappingURL=toHaveDevDependencyComment.matcher.test.js.map