"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yeoman_test_1 = __importDefault(require("yeoman-test"));
describe("CircleCiGenerator", () => {
    let result;
    beforeAll(async () => {
        result = await yeoman_test_1.default.create(__dirname).run();
    });
    describe(".circleci/", () => {
        describe("config.yml", () => {
            it("creates a config.yml file", () => {
                result.assertFile(".circleci/config.yml");
            });
            it("uses the chiubaka/circleci-orb", () => {
                expect(result).toHaveYaml(".circleci/config.yml", {
                    orbs: {
                        chiubaka: "chiubaka/circleci-orb@0.2.0",
                    },
                });
            });
            describe("lint-build-test-publish workflow", () => {
                it("includes a lint-build-test-publish workflow", () => {
                    expect(result).toHaveYaml(".circleci/config.yml", {
                        workflows: {
                            "lint-build-test-publish": {},
                        },
                    });
                });
                it("includes a job for running linters", () => {
                    result.assertFileContent(".circleci/config.yml", "chiubaka/lint");
                });
                it("includes a job for building the project", () => {
                    result.assertFileContent(".circleci/config.yml", "chiubaka/build");
                });
                it("includes a job for running tests", () => {
                    result.assertFileContent(".circleci/config.yml", "chiubaka/test");
                });
                it("includes a job for publishing the package", () => {
                    result.assertFileContent(".circleci/config.yml", "chiubaka/publish");
                });
            });
        });
    });
});
//# sourceMappingURL=CircleCiGenerator.test.js.map