"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitGenerator = void 0;
const node_path_1 = __importDefault(require("node:path"));
const package_symlink_json_1 = __importDefault(require("../package.symlink.json"));
const shared_1 = require("../shared");
const git_hooks_1 = __importDefault(require("./git-hooks"));
class GitGenerator extends shared_1.BaseGenerator {
    constructor() {
        super(...arguments);
        this.configureSubGenerators = () => {
            return [
                {
                    Generator: git_hooks_1.default,
                    path: node_path_1.default.join(__dirname, "./git-hooks"),
                },
            ];
        };
    }
    writing() {
        this.spawnCommandSync("git", ["init"]);
        if (process.env.NODE_ENV === "test" &&
            this.options.configGitUser === true) {
            this.spawnCommandSync("git", ["config", "user.email", "testing@jest.io"]);
            this.spawnCommandSync("git", ["config", "user.name", "Jest"]);
        }
    }
    end() {
        const commitMessage = `Add/update files generated by ${package_symlink_json_1.default.name} v${package_symlink_json_1.default.version}`;
        this.spawnCommandSync("git", ["add", "."]);
        this.spawnCommandSync("git", [
            "commit",
            "-m",
            commitMessage,
            "--no-verify",
        ]);
    }
}
exports.GitGenerator = GitGenerator;
//# sourceMappingURL=GitGenerator.js.map