"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yeoman_test_1 = __importDefault(require("yeoman-test"));
const package_symlink_json_1 = __importDefault(require("../package.symlink.json"));
describe("GitGenerator", () => {
    let result;
    beforeAll(async () => {
        result = await yeoman_test_1.default.create(__dirname)
            .withOptions({ yarnInstall: true, configGitUser: true })
            .run();
    });
    it("initializes a git repo", () => {
        expect(() => {
            result.env.spawnCommandSync("git", ["status"], {});
        }).not.toThrow();
    });
    it("creates a commit for the generated files", () => {
        const commandResult = result.env.spawnCommandSync("git", ["log", "--oneline", "-n", "1"], { stdio: ["ignore", "pipe", "pipe"] });
        const latestCommitMessage = commandResult.stdout;
        expect(latestCommitMessage).toContain(`Add/update files generated by ${package_symlink_json_1.default.name} v${package_symlink_json_1.default.version}`);
    });
    it("leaves the working directory clean", () => {
        const commandResult = result.env.spawnCommandSync("git", ["status", "--porcelain"], { stdio: ["ignore", "pipe", "pipe"] });
        const gitStatus = commandResult.stdout;
        expect(gitStatus).toBe("");
    });
});
//# sourceMappingURL=GitGenerator.test.js.map