"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const yeoman_test_1 = __importDefault(require("yeoman-test"));
describe("GitHooksGenerator", () => {
    let result;
    beforeAll(async () => {
        result = await yeoman_test_1.default.create(node_path_1.default.join(__dirname, "../"))
            .withOptions({ yarnInstall: true, configGitUser: true })
            .run();
    });
    describe("installs necessary dependencies", () => {
        describe("husky", () => {
            it("adds husky to package.json", () => {
                expect(result).toHaveDevDependencyWithComment("husky");
            });
            it("adds a prepare script to install husky in package.json", () => {
                result.assertJsonFileContent("package.json", {
                    scripts: {
                        prepare: "husky install",
                    },
                });
            });
            describe("adds a linting pre-commit hook", () => {
                it("adds a .husky/pre-commit file", () => {
                    result.assertFile(".husky/pre-commit");
                });
                it("lints staged files pre-commit", () => {
                    result.assertFileContent(".husky/pre-commit", "yarn run lint:staged");
                });
            });
            describe("adds a testing pre-push hook", () => {
                it("adds a .husky/pre-push file", () => {
                    result.assertFile(".husky/pre-push");
                });
                it("runs tests pre-push", () => {
                    result.assertFileContent(".husky/pre-push", "yarn run test");
                });
            });
        });
    });
});
//# sourceMappingURL=GitHooksGenerator.test.js.map