"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yeoman_test_1 = __importDefault(require("yeoman-test"));
const __fixtures__1 = require("./__tests__/__fixtures__/");
describe("ReadmeGenerator", () => {
    let result;
    describe("when all shields are enabled", () => {
        beforeAll(async () => {
            result = await yeoman_test_1.default.create(__dirname)
                .withOptions(__fixtures__1.README_GENERATOR_TEST_OPTIONS)
                .run();
        });
        describe("README.md", () => {
            it("creates a README.md file", () => {
                result.assertFile("README.md");
            });
            it("includes the name of the project", () => {
                result.assertFileContent("README.md", "# test-package");
            });
            it("includes the description of the project", () => {
                result.assertFileContent("README.md", "A package generated for tests");
            });
            describe("shields", () => {
                it("includes the NPM shield", () => {
                    const { packageName } = __fixtures__1.README_GENERATOR_TEST_OPTIONS;
                    result.assertFileContent("README.md", `[![npm](https://img.shields.io/npm/v/${packageName})](https://www.npmjs.com/package/${packageName})`);
                });
                it("includes the CircleCI shield", () => {
                    const { repoOwner, repoName } = __fixtures__1.README_GENERATOR_TEST_OPTIONS;
                    result.assertFileContent("README.md", `[![circleci](https://circleci.com/gh/${repoOwner}/${repoName}.svg?style=shield)](https://app.circleci.com/pipelines/github/${repoOwner}/${repoName}?filter=all`);
                });
                it("does not leave a blank line between shields", () => {
                    const { packageName, repoOwner, repoName } = __fixtures__1.README_GENERATOR_TEST_OPTIONS;
                    result.assertFileContent("README.md", `[![npm](https://img.shields.io/npm/v/${packageName})](https://www.npmjs.com/package/${packageName})\n[![circleci](https://circleci.com/gh/${repoOwner}/${repoName}.svg?style=shield)](https://app.circleci.com/pipelines/github/${repoOwner}/${repoName}?filter=all`);
                });
            });
        });
    });
    describe("when includeNpmShield option is false", () => {
        beforeAll(async () => {
            result = await yeoman_test_1.default.create(__dirname)
                .withOptions(Object.assign(Object.assign({}, __fixtures__1.README_GENERATOR_TEST_OPTIONS), { includeNpmShield: false }))
                .run();
        });
        it("does not write the NPM shield", () => {
            const { packageName } = __fixtures__1.README_GENERATOR_TEST_OPTIONS;
            result.assertNoFileContent("README.md", `[![npm](https://img.shields.io/npm/v/${packageName})](https://www.npmjs.com/package/${packageName})`);
        });
    });
    describe("when includeCircleCiShield option is false", () => {
        beforeAll(async () => {
            result = await yeoman_test_1.default.create(__dirname)
                .withOptions(Object.assign(Object.assign({}, __fixtures__1.README_GENERATOR_TEST_OPTIONS), { includeCircleCiShield: false }))
                .run();
        });
        it("does not write the CircleCI shield", () => {
            const { repoOwner: repoOrganization, packageName } = __fixtures__1.README_GENERATOR_TEST_OPTIONS;
            result.assertNoFileContent("README.md", `[![circleci](https://circleci.com/gh/${repoOrganization}/${packageName}.svg?style=shield)](https://app.circleci.com/pipelines/github/${repoOrganization}/${packageName}?filter=all`);
        });
    });
});
//# sourceMappingURL=ReadmeGenerator.test.js.map