"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ErrorUtils_1 = require("./ErrorUtils");
describe("ErrorUtils", () => {
    describe(".isExecException", () => {
        const exception = {
            name: "Test name",
            message: "Test message",
            code: "test code",
            cmd: "test cmd",
            killed: true,
            signal: 1,
            stdout: "test stdout",
            stderr: "test stderr",
        };
        it("returns true when given an error with all the correct properties", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(exception);
            expect(result).toBe(true);
        });
        it("returns true when given an ExecException with null signal", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { signal: null }));
            expect(result).toBe(true);
        });
        it("returns false if error has no name property", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { name: undefined }));
            expect(result).toBe(false);
        });
        it("returns false if error has no message property", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { message: undefined }));
            expect(result).toBe(false);
        });
        it("returns false if error has no cmd property", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { cmd: undefined }));
            expect(result).toBe(false);
        });
        it("returns false if error has no killed property", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { killed: undefined }));
            expect(result).toBe(false);
        });
        it("returns false if error has no code property", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { code: undefined }));
            expect(result).toBe(false);
        });
        it("returns false if error has no signal property", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { signal: undefined }));
            expect(result).toBe(false);
        });
        it("returns false if error has no stdout property", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { stdout: undefined }));
            expect(result).toBe(false);
        });
        it("returns false if error has no stderr property", () => {
            const result = ErrorUtils_1.ErrorUtils.isExecException(Object.assign(Object.assign({}, exception), { stderr: undefined }));
            expect(result).toBe(false);
        });
    });
});
//# sourceMappingURL=ErrorUtils.test.js.map